+++
title = "One verse"
date = 2017-08-01
tags = ["verse"]
draft = false
+++

To preserve the line breaks, indentation and blank lines in a region,
but otherwise use normal formatting, you can use the _verse_
construct, which can also be used to format poetry -- [Reference](https://orgmode.org/manual/Paragraphs.html).

<p class="verse">
Great clouds overhead<br />
Tiny black birds rise and fall<br />
Snow covers Emacs<br />
<br />
&nbsp;&nbsp;&nbsp;&nbsp;-- AlexSchroeder<br />
</p>
